OC.L10N.register(
    "core",
    {
    "Please select a file." : "파일을 선택하십시오.",
    "File is too big" : "파일이 너무 큼",
    "The selected file is not an image." : "선택한 파일은 사진이 아닙니다.",
    "The selected file cannot be read." : "선택한 파일을 읽을 수 없습니다.",
    "Invalid file provided" : "잘못된 파일 지정됨",
    "No image or file provided" : "사진이나 파일이 없음",
    "Unknown filetype" : "알려지지 않은 파일 형식",
    "Invalid image" : "잘못된 사진",
    "An error occurred. Please contact your admin." : "오류가 발생했습니다. 시스템 관리자에게 연락하십시오.",
    "No temporary profile picture available, try again" : "사용 가능한 프로필 사진이 없습니다. 다시 시도하십시오.",
    "No crop data provided" : "선택된 데이터가 없습니다.",
    "No valid crop data provided" : "올바른 잘라내기 데이터가 지정되지 않음",
    "Crop is not square" : "잘라내는 영역이 사각형이 아님",
    "State token does not match" : "상태 토큰이 일치하지 않음",
    "Could not complete login" : "로그인을 할 수 없음",
    "Your login token is invalid or has expired" : "로그인 토큰이 잘못되었거나 만료되었습니다",
    "Password reset is disabled" : "암호 재설정이 비활성화됨",
    "Couldn't reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없습니다",
    "Couldn't reset password because the token is expired" : "토큰이 만료되어 암호를 초기화할 수 없습니다",
    "%s password reset" : "%s 암호 재설정",
    "Password reset" : "암호 재설정",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "아래 단추를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "아래 링크를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
    "Reset your password" : "내 암호 재설정",
    "Nextcloud Server" : "Nextcloud 서버",
    "Some of your link shares have been removed" : "일부 링크 공유가 삭제됨",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "보안 버그로 인하여 일부 링크 공유를 삭제했습니다. 링크를 눌러서 더 많은 정보를 볼 수 있습니다.",
    "Preparing update" : "업데이트 준비 중",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "수리 단계:",
    "Repair info:" : "수리 정보:",
    "Repair warning:" : "수리 경고:",
    "Repair error:" : "수리 오류:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "config.php에서 자동 업데이트가 비활성화되어 있기 때문에 명령줄 업데이트를 사용하십시오.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: 테이블 %s 확인 중",
    "Turned on maintenance mode" : "유지 보수 모드 켜짐",
    "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
    "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
    "Updating database schema" : "데이터베이스 스키마 업데이트 중",
    "Updated database" : "데이터베이스 업데이트됨",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
    "Checked database schema update" : "데이터베이스 스키마 업데이트 확인됨",
    "Checking updates of apps" : "앱 업데이트 확인 중",
    "Checking for update of app \"%s\" in appstore" : "앱 스토어에서 \"%s\" 앱의 업데이트를 확인하는 중",
    "Update app \"%s\" from appstore" : "앱 스토어에서 \"%s\" 앱 업데이트",
    "Checked for update of app \"%s\" in appstore" : "앱 스토어에서 \"%s\" 앱 업데이트 확인함",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s의 데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
    "Checked database schema update for apps" : "앱용 데이터베이스 스키마 업데이트 확인됨",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\"을(를) %2$s(으)로 업데이트함",
    "Set log level to debug" : "로그 단계를 디버그로 설정",
    "Reset log level" : "로그 단계 초기화",
    "Starting code integrity check" : "코드 무결성 검사 시작 중",
    "Finished code integrity check" : "코드 무결성 검사 완료됨",
    "%s (incompatible)" : "%s(호환 불가)",
    "Following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
    "Already up to date" : "최신 상태임",
    "Very weak password" : "매우 약한 암호",
    "Weak password" : "약한 암호",
    "So-so password" : "그저 그런 암호",
    "Good password" : "좋은 암호",
    "Strong password" : "강력한 암호",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 인터페이스를 사용할 수 없어서 웹 서버에서 파일 동기화를 사용할 수 있도록 설정할 수 없습니다.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "웹 서버에서 \"{url}\"을(를) 올바르게 처리할 수 없습니다. 더 많은 정보를 보려면 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "웹 서버에서 \"{url}\" 주소를 올바르게 처리할 수 있도록 설정되지 않았습니다. 웹 서버 설정이 이 폴더를 직접 전달하도록 업데이트되지 않은 것과 연관되었을 수도 있습니다. Apache용 \".htaccess\" Rewrite 규칙이나 Nginx <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서 페이지</a>에 있는 것과 현재 설정을 비교해 보십시오. Nginx의 경우 \"location ~\"로 시작하는 줄을 업데이트해야 할 수도 있습니다.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "웹 서버에서 .woff2 파일을 제대로 전달하도록 설정하지 않았습니다. Nginx 설정 문제일 수 있습니다. Nextcloud 15에서는 .woff2 파일을 올바르게 제공하려면 설정을 변경해야 합니다. 현재 Nginx 설정과 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>에 있는 권장 설정을 비교해 보십시오.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP에서 시스템 환경 변수를 올바르게 조회할 수 없는 것 같습니다. getenv(\"PATH\") 시험 결과 빈 값이 반환되었습니다.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "서버 PHP 설정(특히 php-fpm 사용 시)에 관한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">설치 문서↗</a>를 참조하십시오.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "데이터베이스가 \"READ COMMITTED\" 트랜잭션 격리 수준에서 실행되고 있지 않습니다. 여러 작업이 동시에 실행될 때 문제가 발생할 수 있습니다.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP의 \"fileinfo\" 모듈이 없습니다. 올바른 MIME 형식 감지를 위해서 이 모듈을 활성화하는 것을 추천합니다.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "트랜잭션 파일 잠금이 비활성화되어 있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 \"filelocking.enabled\"를 활성화하여 이 문제를 해결할 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">사용 설명서 ↗</a>를 참고하십시오.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "도메인의 루트 경로에 설치되어 있지 않고 시스템 Cron을 사용한다면 URL 생성에 문제가 발생할 수도 있습니다. 이 문제를 예방하려면 config.php의 \"overwrite.cli.url\" 옵션을 설치본의 웹 루트 경로로 설정하십시오(제안: \"{suggestedOverwriteCliURL}\")",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI로 cron 작업을 실행시킬 수 없었습니다. 다음 오류가 발생했습니다:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "마지막 백그라운드 작업이 {relativeTime}에 실행되었습니다. 문제가 발생한 것 같습니다.",
    "Check the background job settings" : "백그라운드 작업 설정 확인",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "웹 서버에서 인터넷에 연결할 수 없습니다. 여러 종단점에 접근할 수 없습니다. 외부 저장소 마운트, 업데이트 알림, 추가 앱 설치 등 기능이 작동하지 않을 것입니다. 원격으로 파일에 접근하거나 알림 이메일을 보내지 못할 수도 있습니다. 모든 기능을 사용하려면 이 서버를 인터넷에 연결하십시오.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "메모리 캐시가 구성되지 않았습니다. 가능한 경우 memcache를 설정하여 성능을 향상시킬 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP가 안전한 난수 발생기를 사용할 수 없어 보안에 취약합니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "현재 PHP {version}을(를) 사용하고 있습니다. 배포판에서 지원하는 대로 PHP 버전을 업그레이드하여 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">PHP 그룹에서 제공하는 성능 및 보안 업데이트</a>를 받는 것을 추천합니다.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "PHP 5.6을 실행하고 있습니다. 현재 사용하고 있는 Nextcloud의 주 버전은 PHP 5.6을 지원하는 마지막 버전입니다. Nextcloud 14로 업그레이드하려면 PHP 7.0 이상으로 업그레이드하십시오.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "역방향 프록시 헤더 설정이 올바르지 않거나 신뢰하는 프록시를 통해 Nextcloud에 접근하고 있을 수 있습니다. 만약 Nextcloud를 신뢰하는 프록시를 통해 접근하고 있지 않다면 이는 보안 문제이며 공격자가 Nextcloud에 보이는 IP 주소를 속이고 있을 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached가 분산 캐시로 구성되어 있지만 잘못된 PHP 모듈 \"memcache\"가 설치되어 있습니다. \\OC\\Memcache\\Memcached는 \"memcache\"가 아닌 \"memcached\"만 지원합니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">이 두 모듈에 대한 memcached 위키</a>를 참고하십시오.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "일부 파일이 무결성 검사를 통과하지 못했습니다. 이 문제를 해결하는 방법은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.(<a href=\"{codeIntegrityDownloadEndpoint}\">잘못된 파일 목록…</a> / <a href=\"{rescanEndpoint}\">다시 검색…</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "PHP OPcache 모듈을 불러오지 않았습니다. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">더 나은 성능을 위해 PHP 설치에 위 기능을 불러오는 것을 권장합니다.</a>",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP Opcache가 제대로 설정되어 있지 않습니다. 더 나은 성능을 위해서 <code>php.ini</code> 파일에 다음 설정을 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">추가하는 것을 권장합니다</a>:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP 함수 \"set_time_limit\"을 사용할 수 없습니다. 스크립트가 실행 중간에 중지되어 설치를 깨트릴 수도 있습니다. 이 함수를 활성화하는 것을 추천합니다.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP에 Freetype 지원이 없습니다. 프로필 사진과 설정 인터페이스가 올바르게 표시되지 않을 수도 있습니다.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "테이블 \"{tableName}\"에 인덱스 \"{indexName}\"이(가) 없습니다.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "데이터베이스에 일부 인덱스가 없습니다. 큰 테이블에 인덱스를 추가하는 데 시간이 걸리기 때문에 자동으로 추가하지 않았습니다. 명령행에서 \"occ db:add-missing-indices\" 명령을 실행하여 인스턴스를 실행하는 동안 수동으로 인덱스를 추가할 수 있습니다. 해당 테이블에 인덱스를 추가하면 질의 속도가 다시 빨라집니다.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "이 인스턴스에 추천하는 PHP 모듈 중 일부가 존재하지 않습니다. 성능 향상과 호환성을 위하여 PHP 모듈을 설치하는 것을 추천합니다.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "일부 데이터베이스 열이 Big Int로 변환되지 않았습니다. 큰 테이블의 열 형식을 변환하는 데 시간이 걸리기 때문에 자동으로 변환하지 않았습니다. 명령행에서 \"occ db:convert-filecache-bigint\" 명령을 실행하여 변경 사항을 직접 적용할 수 있습니다. 이 작업은 인스턴스를 오프라인으로 전환하고 실행해야 합니다. 더 많은 정보를 보려면 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서 페이지</a>를 참조하십시오.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "현재 백엔드 데이터베이스로 SQLite를 사용하고 있습니다. 대규모의 파일을 관리하려고 한다면 다른 데이터베이스 백엔드로 전환할 것을 권장합니다.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정인 경우 권장됩니다.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "다른 데이터베이스로 마이그레이션하려면 'occ db:convert-type' 명령행 도구를 사용하거나 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">사용 설명서 ↗</a>를 참고하십시오.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "PHP 내장 Mailer 모듈은 더 이상 지원되지 않습니다. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">이메일 설정을 업데이트해 주십시오↗<a/>.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP 메모리 제한이 추천값인 512MB보다 작습니다.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "일부 앱 디렉터리를 웹 서버 사용자와 다른 사용자가 소유하고 있습니다. 수동으로 앱을 설치한 경우에 발생할 수 있습니다. 다음 앱 디렉터리의 사용 권한을 확인하십시오:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "데이터베이스로 MySQL을 사용하고 있지만 4바이트 문자를 지원하지 않습니다. 파일 이름, 댓글 등에 에모지와 같은 4바이트 문자를 문제 없이 지원하려면 MySQL에서 4바이트 지원을 활성화해야 합니다. 더 많은 정보를 보려면 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서 페이지</a>를 참조하십시오.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "이 인스턴스에서 S3 기반 객체 저장소를 주 저장소로 사용하고 있습니다. 업로드한 파일을 서버에 임시로 저장하기 때문에 PHP 임시 디렉터리에 최소 50 GB의 빈 공간을 두는 것을 추천합니다. 전체 경로와 사용 가능한 정보를 보려면 로그를 참조하십시오. 성능을 개선하려면 php.ini의 임시 디렉터리를 변경하거나, 해당 위치에서 사용할 수 있는 공간을 더 많이 할당하십시오.",
    "Error occurred while checking server setup" : "서버 설정을 확인하는 중 오류 발생",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "데이터 디렉터리와 파일을 인터넷에서 접근할 수 있는 것 같습니다. .htaccess 파일을 사용할 수 없습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 디렉터리 밖으로 옮기는 것을 추천합니다.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP 헤더가 \"{expected}\"(으)로 설정되어 있지 않습니다. 잠재적인 정보 유출 및 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP 헤더가 \"{expected}\"(으)로 설정되어 있지 않습니다. 일부 기능이 올바르게 작동하지 않을 수 있으므로 설정을 변경하는 것을 추천합니다.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP 헤더가 \"{expected}\"을(를) 포함하고 있지 않습니다. 잠재적인 정보 유출 및 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "\"{header}\" HTTP 헤더가 \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" 또는 \"{val5}\"(으)로 설정되어 있지 않습니다. 추가 정보가 유출될 수 있습니다. 자세한 사항은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C 추천 ↗</a>을 참조하십시오.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP 헤더가 \"{seconds}\"초 이상으로 설정되어 있지 않습니다. <a href=\"{docUrl}\" rel=\"noreferrer noopener\">보안 팁</a>에서 제안하는 것처럼 HSTS를 활성화하는 것을 추천합니다.",
    "Non-existing tag #{tag}" : "존재하지 않는 태그 #{tag}",
    "restricted" : "제한됨",
    "invisible" : "보이지 않음",
    "({scope})" : "({scope})",
    "Delete" : "삭제",
    "Rename" : "이름 바꾸기",
    "Collaborative tags" : "협동 태그",
    "No tags found" : "태그를 찾을 수 없음",
    "unknown text" : "알 수 없는 텍스트",
    "Hello world!" : "Hello world!",
    "sunny" : "맑음",
    "Hello {name}, the weather is {weather}" : "{name} 님 안녕하세요, 오늘 날씨는 {weather}입니다",
    "Hello {name}" : "{name} 님 안녕하세요",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>검색 결과입니다<script>alert(1)</script></strong>",
    "new" : "새로운 항목",
    "_download %n file_::_download %n files_" : ["파일 %n개 다운로드"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "업데이트 중입니다. 일부 환경에서 이 페이지를 닫을 경우 작업이 중단될 수 있습니다.",
    "Update to {version}" : "{version}(으)로 업데이트",
    "An error occurred." : "오류가 발생했습니다.",
    "Please reload the page." : "페이지를 새로 고치십시오.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "업데이트에 실패했습니다. 더 많은 정보를 보려면 이 문제에 대한 <a href=\"{url}\">포럼 글</a>을 참조하십시오.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "업데이트가 실패했습니다. 이 문제를 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 커뮤니티</a>에 보고하여 주십시오.",
    "Continue to Nextcloud" : "Nextcloud로 계속 진행",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["업데이트가 성공했습니다. %n초 후 Nextcloud로 이동합니다."],
    "Searching other places" : "다른 장소 찾는 중",
    "No search results in other folders for {tag}{filter}{endtag}" : "다른 폴더에 {tag}{filter}{endtag} 검색 결과가 없음",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["다른 폴더의 검색 결과 {count}개"],
    "Server side authentication failed!" : "서버 인증 실패!",
    "Please contact your administrator." : "관리자에게 문의하십시오.",
    "An internal error occurred." : "내부 오류가 발생했습니다.",
    "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
    "Username or email" : "사용자 이름 또는 이메일",
    "Password" : "암호",
    "Log in" : "로그인",
    "Logging in …" : "로그인 중 …",
    "Wrong username or password." : "사용자 이름이나 암호가 잘못되었습니다.",
    "User disabled" : "사용자 비활성화됨",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "사용 중인 IP에서 여러 번의 잘못된 로그인 시도를 감지했습니다. 30초 후에 다시 로그인할 수 있습니다.",
    "Reset password" : "암호 재설정",
    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
    "Password can not be changed. Please contact your administrator." : "암호를 변경할 수 없습니다. 관리자에게 문의하십시오.",
    "Back to login" : "로그인으로 돌아가기",
    "New password" : "새 암호",
    "I know what I'm doing" : "지금 하려는 것을 알고 있습니다",
    "Cancel" : "취소",
    "Forgot password?" : "암호를 잊으셨습니까?",
    "Settings" : "설정",
    "Could not load your contacts" : "연락처를 불러올 수 없음",
    "Search contacts …" : "연락처 검색…",
    "No contacts found" : "연락처를 찾을 수 없음",
    "Show all contacts …" : "모든 연락처 보기 …",
    "Loading your contacts …" : "연락처 불러오는 중 …",
    "Looking for {term} …" : "{term} 검색 중 …",
    "No" : "아니요",
    "Yes" : "예",
    "No files in here" : "여기에 파일이 없음",
    "New folder" : "새 폴더",
    "No more subfolders in here" : "더 이상의 하위 폴더 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정한 날짜",
    "{newName} already exists" : "{newName}이(가) 이미 존재함",
    "Choose" : "선택",
    "Copy" : "복사",
    "Move" : "이동",
    "Error loading file picker template: {error}" : "파일 선택 템플릿을 불러오는 중 오류 발생: {error}",
    "OK" : "확인",
    "Error loading message template: {error}" : "메시지 템플릿을 불러오는 중 오류 발생: {error}",
    "read-only" : "읽기 전용",
    "_{count} file conflict_::_{count} file conflicts_" : ["파일 {count}개 충돌"],
    "One file conflict" : "파일 1개 충돌",
    "New Files" : "새 파일",
    "Already existing files" : "파일이 이미 존재합니다",
    "Which files do you want to keep?" : "어느 파일을 유지하시겠습니까?",
    "If you select both versions, the copied file will have a number added to its name." : "두 버전을 모두 선택하면 복사된 파일 이름에 번호가 추가됩니다.",
    "Continue" : "계속",
    "(all selected)" : "(모두 선택됨)",
    "({count} selected)" : "({count}개 선택됨)",
    "Error loading file exists template" : "파일 존재함 템플릿을 불러오는 중 오류 발생",
    "Pending" : "보류 중",
    "Copy to {folder}" : "{folder}에 복사",
    "Move to {folder}" : "{folder}(으)로 이동",
    "Saving..." : "저장 중...",
    "Authentication required" : "인증 필요",
    "This action requires you to confirm your password" : "이 작업을 수행하려면 암호를 입력해야 합니다",
    "Confirm" : "확인",
    "Failed to authenticate, try again" : "인증할 수 없습니다. 다시 시도하십시오.",
    "seconds ago" : "초 전",
    "Connection to server lost" : "서버 연결이 끊어짐",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["페이지 불러오기 오류, %n초 후 새로 고침"],
    "Add to a project" : "프로젝트에 추가",
    "Hide details" : "자세한 정보 숨기기",
    "Connect items to a project to make them easier to find" : "폴더 또는 파일을 찾기 쉽게 프로젝트에 연결하세요.",
    "Type to search for existing projects" : "이미 존재하는 프로젝트를 찾기 위해 입력하세요.",
    "New in" : "새로운 것",
    "View changelog" : "변경 기록 확인",
    "No action available" : "사용할 수 있는 동작 없음",
    "Error fetching contact actions" : "연락처 동작을 가져오는 중 오류 발생",
    "Personal" : "개인",
    "Users" : "사용자",
    "Apps" : "앱",
    "Admin" : "관리자",
    "Help" : "도움말",
    "Access forbidden" : "접근 금지됨",
    "File not found" : "파일을 찾을 수 없음",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "서버에서 문서를 찾을 수 없습니다. 공유가 삭제되었거나 만료되었습니까?",
    "Back to %s" : "%s(으)로 돌아가기",
    "Error" : "오류",
    "Internal Server Error" : "내부 서버 오류",
    "The server was unable to complete your request." : "서버에서 요청을 처리할 수 없습니다.",
    "If this happens again, please send the technical details below to the server administrator." : "만약 이 오류가 다시 발생하면 서버 관리자에게 다음 기술 정보를 알려 주십시오.",
    "More details can be found in the server log." : "서버 로그에서 자세한 정보를 찾을 수 있습니다.",
    "Technical details" : "기술 정보",
    "Remote Address: %s" : "원격 주소: %s",
    "Request ID: %s" : "요청 ID: %s",
    "Type: %s" : "종류: %s",
    "Code: %s" : "코드: %s",
    "Message: %s" : "메시지: %s",
    "File: %s" : "파일: %s",
    "Line: %s" : "줄: %s",
    "Trace" : "추적",
    "Security warning" : "보안 경고",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수도 있습니다.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "서버를 올바르게 설정하는 방법에 대해서 더 알아보려면 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">문서</a>를 참조하십시오.",
    "Create an <strong>admin account</strong>" : "<strong>관리자 계정</strong> 만들기",
    "Username" : "사용자 이름",
    "Storage & database" : "저장소 및 데이터베이스",
    "Data folder" : "데이터 폴더",
    "Configure the database" : "데이터베이스 설정",
    "Only %s is available." : "%s만 사용할 수 있습니다.",
    "Install and activate additional PHP modules to choose other database types." : "다른 데이터베이스 종류를 사용하려면 추가 PHP 모듈을 설치 및 활성화하십시오.",
    "For more details check out the documentation." : "자세한 정보를 보려면 문서를 참고하십시오.",
    "Database user" : "데이터베이스 사용자",
    "Database password" : "데이터베이스 암호",
    "Database name" : "데이터베이스 이름",
    "Database tablespace" : "데이터베이스 테이블 공간",
    "Database host" : "데이터베이스 호스트",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "호스트 이름과 함께 포트 번호를 지정하십시오(예: localhost:5432)",
    "Performance warning" : "성능 경고",
    "You chose SQLite as database." : "데이터베이스로 SQLite를 선택하셨습니다.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite는 최소 및 개발 목적의 인스턴스에만 사용하는 것을 추천합니다. 실제 업무에 사용하려면 다른 데이터베이스 백엔드를 사용하십시오.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "만약 파일 동기화 클라이언트를 사용하려고 한다면 SQLite를 사용하지 않는 것이 좋습니다.",
    "Finish setup" : "설치 완료",
    "Finishing …" : "완료 중 …",
    "Need help?" : "도움이 필요한가요?",
    "See the documentation" : "문서 보기",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud를 다시 설치하려고 하는 것 같습니다. 그러나 현재 설정 디렉터리에 CAN_INSTALL 파일이 없는 것 같습니다. 계속 진행하려면 설정 폴더에 CAN_INSTALL 폴더를 만드십시오.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "설정 폴더에서 CAN_INSTALL 파일을 삭제할 수 없습니다. 직접 삭제하십시오.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "이 프로그램이 올바르게 작동하려면 자바스크립트가 필요합니다. {linkstart}자바스크립트를 활성화{linkend}한 다음 페이지를 새로 고치십시오.",
    "Get your own free account" : "무료 계정 등록",
    "Skip to main content" : "주 내용으로 이동",
    "Skip to navigation of app" : "앱 탐색으로 이동",
    "More apps" : "더 많은 앱",
    "More" : "더 보기",
    "More apps menu" : "더 많은 앱 메뉴",
    "Search" : "검색",
    "Reset search" : "검색 초기화",
    "Contacts" : "연락처",
    "Contacts menu" : "연락처 메뉴",
    "Settings menu" : "설정 메뉴",
    "Confirm your password" : "암호 확인",
    "Connect to your account" : "내 계정에 연결",
    "Please log in before granting %1$s access to your %2$s account." : "%1$s에서 내 %2$s 계정에 접근하는 것을 허용하려면 로그인해야 합니다.",
    "App token" : "앱 토큰",
    "Grant access" : "접근 허용",
    "Alternative log in using app token" : "앱 토큰으로 대체 로그인",
    "Account access" : "계정 접근",
    "You are about to grant %1$s access to your %2$s account." : "%1$s에서 내 %2$s 계정에 접근하는 것을 허용하려고 합니다.",
    "Account connected" : "계정 연결됨",
    "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다.",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 시도하십시오",
    "Two-factor authentication" : "2단계 인증",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "현재 계정에 향상된 보안이 켜져 있습니다. 2단계 인증 방식을 선택하십시오:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "2단계 인증 방식을 불러올 수 없습니다. 관리자에게 문의하십시오.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "2단계 인증이 필수로 설정되어 있지만 현재 계정에 설정되어 있지 않습니다. 관리자에게 도움을 요청하십시오.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "2단계 인증이 필수로 설정되어 있지만 현재 계정에 설정되어 있지 않습니다. 계속 진행하여 2단계 인증을 설정하십시오.",
    "Set up two-factor authentication" : "2단계 인증 설정",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "2단계 인증이 필수로 설정되어 있지만 현재 계정에 설정되어 있지 않습니다. 백업 코드를 사용하여 로그인하거나 관리자에게 도움을 요청하십시오.",
    "Use backup code" : "백업 코드 사용",
    "Cancel login" : "로그인 취소",
    "Setup two-factor authentication" : "2단계 인증 설정",
    "Error while validating your second factor" : "2단계 인증을 검증하는 중 오류 발생",
    "Access through untrusted domain" : "신뢰하지 않는 도메인으로 접근",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "시스템 관리자에게 연락하십시오. 만약 시스템 관리자라면 config/config.php의 \"trusted_domains\" 설정을 config.sample.php를 참조하여 편집하십시오.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "설정하는 방법에 대한 정보는 %1$s문서%2$s에서 찾을 수 있습니다.",
    "App update required" : "앱 업데이트 필요",
    "%1$s will be updated to version %2$s" : "%1$s을(를) 버전 %2$s(으)로 업데이트합니다.",
    "These apps will be updated:" : "다음 앱을 업데이트합니다:",
    "These incompatible apps will be disabled:" : "다음 호환되지 않는 앱이 비활성화됩니다:",
    "The theme %s has been disabled." : "%s 테마가 비활성화되었습니다.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "계속하기 전에 데이터베이스, 설정 폴더, 데이터 폴더가 백업되어 있는지 확인하십시오.",
    "Start update" : "업데이트 시작",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "큰 파일을 설치하는 경우 시간이 초과될 수 있으므로, 설치 디렉터리에서 다음 명령을 실행하셔도 됩니다:",
    "Detailed logs" : "자세한 로그",
    "Update needed" : "업데이트 필요",
    "Please use the command line updater because you have a big instance with more than 50 users." : "현재 인스턴스에 50명 이상의 사용자가 있기 때문에 명령행 업데이터를 사용하십시오.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "도움말을 보려면 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">문서</a>를 참조하십시오.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "웹 UI를 통한 업데이트 시 요청 시간이 초과되어 데이터가 손실될 수 있는 위험성을 알고 있으며, 내 데이터를 백업해 두었고 실패한 경우 복원할 수 있는 방법을 알고 있습니다.",
    "Upgrade via web on my own risk" : "그래도 웹으로 업데이트하기",
    "Maintenance mode" : "유지 보수 모드",
    "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
    "This page will refresh itself when the instance is available again." : "인스턴스를 다시 사용할 수 있을 때 페이지를 자동으로 새로 고칩니다.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "이 사용자 이름과 연결된 이메일 주소가 없어서 초기화 메일을 보낼 수 없습니다. 시스템 관리자에게 연락하십시오.",
    "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
    "Dismiss" : "닫기",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 포함하고 있는 이메일을 보냈습니다. 이메일이 도착하지 않은 경우 스팸함을 확인해 보십시오.<br>스팸함에도 없는 경우 로컬 관리자에게 문의하십시오.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "내 파일이 암호화되어 있습니다. 암호를 초기화하면 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 시스템 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
    "Sending email …" : "이메일 보내는 중…",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name}의 버전 {version} 미만이 설치되어 있습니다. 안정성과 성능을 위해 {name}의 새로운 버전으로 업데이트하는 것을 권장합니다.",
    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "사이트에 HTTP를 통해서 보안 없이 접근하고 있습니다. <a href=\"{docUrl}\">보안 팁↗</a>에서 제안하는 것처럼 HTTPS를 설정하는 것을 추천합니다.",
    "Shared" : "공유됨",
    "Shared with" : "다음 사용자와 공유함",
    "Shared by" : "다음 사용자가 공유함",
    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
    "Choose a password for the public link or press the \"Enter\" key" : "공개 림크 암호를 입력하거나 \"Enter\" 키를 누르십시오",
    "Copied!" : "복사 성공!",
    "Copy link" : "링크 복사",
    "Not supported!" : "지원하지 않음!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
    "Unable to create a link share" : "공유 링크를 만들 수 없습니다.",
    "Unable to toggle this option" : "이 설정을 전환할 수 없음",
    "Resharing is not allowed" : "다시 공유할 수 없음",
    "Link" : "링크",
    "Hide download" : "다운로드 숨기기",
    "Password protection enforced" : "암호 보호 적용",
    "Password protect" : "암호 보호",
    "Allow editing" : "편집 허용",
    "Email link to person" : "이메일 주소",
    "Send" : "전송",
    "Allow upload and editing" : "업로드 및 편집 허용",
    "Read only" : "읽기 전용",
    "File drop (upload only)" : "파일 보관소(업로드만 허용)",
    "Expiration date enforced" : "만료 날짜 적용",
    "Set expiration date" : "만료 날짜 설정",
    "Expiration" : "만료",
    "Expiration date" : "만료 날짜",
    "Note to recipient" : "받는 사람 메모",
    "Unshare" : "공유 해제",
    "Delete share link" : "공유 링크 삭제",
    "Add another link" : "다른 링크 추가",
    "Password protection for links is mandatory" : "링크 암호 보호는 필수입니다",
    "Share to {name}" : "{name} 님에게 공유",
    "Share link" : "링크 공유",
    "New share link" : "새 공유 링크",
    "Created on {time}" : "{time}에 생성됨",
    "Password protect by Talk" : "토크에서 암호로 보호됨",
    "Could not unshare" : "공유 해제할 수 없음",
    "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유함",
    "Shared with you and {circle} by {owner}" : "{owner} 님이 여러분과 {circle}와(과) 공유함",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 님이 여러분과 대화 {conversation}와(과) 공유함",
    "Shared with you in a conversation by {owner}" : "{owner} 님이 대화에서 여러분과 공유함",
    "Shared with you by {owner}" : "{owner} 님이 여러분과 공유함",
    "Choose a password for the mail share" : "이메일 공유 암호 입력",
    "group" : "그룹",
    "remote" : "원격",
    "remote group" : "원격 그룹",
    "email" : "이메일",
    "conversation" : "대화",
    "shared by {sharer}" : "{sharer} 님이 공유함",
    "Can reshare" : "재공유 가능",
    "Can edit" : "편집 가능",
    "Can create" : "생성 가능",
    "Can change" : "변경 가능",
    "Can delete" : "삭제 가능",
    "Access control" : "접근 제어",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 님이 링크로 공유함",
    "Error while sharing" : "공유하는 중 오류 발생",
    "Share details could not be loaded for this item." : "이 항목의 공유 정보를 불러올 수 없습니다.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["자동 완성을 시작하려면 최소 {count}글자를 입력해야 합니다"],
    "This list is maybe truncated - please refine your search term to see more results." : "결과 목록이 잘렸을 수도 있습니다. 검색할 단어를 더 정확히 입력해서 더 많은 결과를 보십시오.",
    "No users or groups found for {search}" : "{search} 사용자나 그룹을 찾을 수 없음",
    "No users found for {search}" : "{search} 사용자를 찾을 수 없음",
    "An error occurred (\"{message}\"). Please try again" : "오류가 발생했습니다(\"{message}\"). 다시 시도하십시오",
    "An error occurred. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
    "Home" : "홈",
    "Work" : "작업",
    "Other" : "기타",
    "{sharee} (remote group)" : "{sharee}(원격 그룹)",
    "{sharee} ({type}, {owner})" : "{sharee}({type}, {owner})",
    "Share" : "공유",
    "Name or email address..." : "이름이나 이메일 주소...",
    "Name or federated cloud ID..." : "이름이나 연합 클라우드 ID...",
    "Name, federated cloud ID or email address..." : "이름, 연합 클라우드 ID 및 이메일 주소...",
    "Name..." : "이름...",
    "Error removing share" : "공유 삭제 중 오류 발생",
    "SQLite will be used as database." : "데이터베이스로 SQLite를 사용할 것입니다.",
    "For larger installations we recommend to choose a different database backend." : "대규모 파일을 관리하려고 한다면 다른 데이터베이스 백엔드를 선택할 것을 권장합니다.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정이면 SQLite를 사용하지 않는 것이 좋습니다.",
    "Wrong password." : "암호가 잘못되었습니다.",
    "New Password" : "새 암호",
    "Cancel log in" : "로그인 취소",
    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 이 계정에 연결된 이메일 주소로 보냈습니다. 일정 시간이 지난 후에도 이메일을 받지 못했다면 스팸 메일함을 확인해 보십시오.<br>스팸 메일함에도 링크가 없다면 시스템 관리자에게 문의하십시오.",
    "Search globally" : "전역 검색",
    "Your client should now be connected! You can close this window." : "클라이언트가 연동되었습니다! 이제 창을 닫으셔도 됩니다."
},
"nplurals=1; plural=0;");
